package com.ruoyi.project.sems.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.sems.domain.TReportPatrol;

/**
 * 月度检查巡检记录Mapper接口
 *
 * @author ruoyi
 * @date 2021-09-01
 */
public interface TReportPatrolMapper
{
    /**
     * 查询月度检查巡检记录
     *
     * @param id 月度检查巡检记录ID
     * @return 月度检查巡检记录
     */
    public TReportPatrol selectTReportPatrolById(Long id);

    /**
     * 查询月度检查巡检记录
     *
     * @param reportId 月度检查ID
     * @return 月度检查巡检记录
     */
    public List<TReportPatrol> selectTReportPatrolByMonthId(Long reportId);

    /**
     * 查询月度检查巡检记录列表
     *
     * @param tReportPatrol 月度检查巡检记录
     * @return 月度检查巡检记录集合
     */
    public List<TReportPatrol> selectTReportPatrolList(TReportPatrol tReportPatrol);

    /**
     * 新增月度检查巡检记录
     *
     * @param tReportPatrol 月度检查巡检记录
     * @return 结果
     */
    public int insertTReportPatrol(TReportPatrol tReportPatrol);

    /**
     * 修改月度检查巡检记录
     *
     * @param tReportPatrol 月度检查巡检记录
     * @return 结果
     */
    public int updateTReportPatrol(TReportPatrol tReportPatrol);

    /**
     * 删除月度检查巡检记录
     *
     * @param id 月度检查巡检记录ID
     * @return 结果
     */
    public int deleteTReportPatrolById(Long id);

    /**
     * 批量删除月度检查巡检记录
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTReportPatrolByIds(Long[] ids);
}
